@@ -12,26 +12,17 @@ knitr::opts_chunk$set(
 ## -----------------------------------------------------------------------------
 
 library(manymodelr)
+data("yields", package="manymodelr")
 
 
 ## -----------------------------------------------------------------------------
-
-head(agg_by_group(iris,.~Species,length))
-
-
-## -----------------------------------------------------------------------------
-
-head(agg_by_group(mtcars,cyl~hp+vs,sum))
-
-
-## -----------------------------------------------------------------------------
-
 set.seed(520)
-train_set<-createDataPartition(iris$Species,p=0.8,list=FALSE)
-valid_set<-iris[-train_set,]
-train_set<-iris[train_set,]
+train_set<-createDataPartition(yields$normal,p=0.6,list=FALSE)
+valid_set<-yields[-train_set,]
+train_set<-yields[train_set,]
 ctrl<-trainControl(method="cv",number=5)
-m<-multi_model_1(train_set,"Species",".",c("knn","rpart"), "Accuracy",ctrl,new_data =valid_set)
+m<-multi_model_1(train_set,"normal",".",c("knn","rpart"), 
+                 "Accuracy",ctrl,new_data =valid_set)
 
 
 ## -----------------------------------------------------------------------------
@@ -46,28 +37,43 @@ head(m$predictions)
 
 ## -----------------------------------------------------------------------------
 # fit a linear model and get predictions
-lin_model <- multi_model_2(iris[1:50,],iris[50:99,],"Sepal.Length","Petal.Length","lm")
+lin_model <- multi_model_2(mtcars[1:16,],mtcars[17:32,],"mpg","wt","lm")
 
-head(lin_model)
+lin_model[c("predicted", "mpg")]
 
 
 ## -----------------------------------------------------------------------------
 
-head(multi_model_2(iris[1:50,],iris[50:99,],"Sepal.Length", "Petal.Length +Sepal.Width","lm"))
+multi_lin <- multi_model_2(mtcars[1:16, ], mtcars[17:32,],"mpg", "wt + disp + drat","lm")
+
+multi_lin[,c("predicted", "mpg")]
 
 
 ## -----------------------------------------------------------------------------
-
-head(multi_model_2(iris[1:50,],iris[50:99,],"Sepal.Length","Petal.Length + I(Sepal.Width)**2","lm"))
-
-
-## -----------------------------------------------------------------------------
-iris1 <- iris[1:50,]
-iris2 <- iris[51:100,]
-lm_model <- fit_model(iris1,"Sepal.Length","Petal.Length","lm")
+lm_model <- fit_model(mtcars,"mpg","wt","lm")
 lm_model
 
 
+## -----------------------------------------------------------------------------
+
+models<-fit_models(df=yields,yname=c("height", "weight"),xname="yield",
+                   modeltype="glm") 
+
+
+## -----------------------------------------------------------------------------
+
+
+res_residuals <- lapply(models[[1]], add_model_residuals,yields)
+res_predictions <- lapply(models[[1]], add_model_predictions, yields, yields)
+# Get height predictions for the model height ~ yield 
+head(res_predictions[[1]])
+
+
+## -----------------------------------------------------------------------------
+fit_models(df=yields,yname=c("height","weight"),
+           xname=".",modeltype=c("lm","glm"), drop_non_numeric = TRUE)
+
+
 ## -----------------------------------------------------------------------------
 
 extract_model_info(lm_model, "r2")
@@ -88,58 +94,6 @@ extract_model_info(lm_model, "p_value")
 extract_model_info(lm_model,c("p_value","response","call","predictors"))
 
 
-## -----------------------------------------------------------------------------
-# select only column 6 that has our predicted values
-
-head(add_model_predictions(lm_model, old_data = iris1, new_data =  iris2))[6]
-
-
-## -----------------------------------------------------------------------------
-
-library(dplyr)
-iris1 %>% 
-  add_model_predictions(model=lm_model,new_data = iris2) %>% 
-  select(predicted, everything()) %>% 
-  head()
-
-
-## -----------------------------------------------------------------------------
-# 6 since residuals are added as the final column of the dataset
-
-head(add_model_residuals(lm_model, iris1)[6])
-
-
-## -----------------------------------------------------------------------------
-
-iris1 %>% 
-  add_model_residuals(model=lm_model) %>% 
-  add_model_predictions(new_data = iris2, model = lm_model) %>% 
-  select(predicted,residuals, everything()) %>% 
-  head()
-
-
-## -----------------------------------------------------------------------------
-
-( models<-fit_models(df=iris,yname=c("Sepal.Length","Sepal.Width"),xname="Petal.Length + Petal.Width",modeltype="lm") )
-
-
-## -----------------------------------------------------------------------------
-
-res<-lapply(models,add_model_residuals,iris)
-
-head(res[[1]])
-
-
-## -----------------------------------------------------------------------------
-
-fit_models(df=iris,yname=c("Sepal.Length","Sepal.Width"), xname="Petal.Length + Petal.Width",modeltype=c("lm","glm"))
-
-
-## -----------------------------------------------------------------------------
-fit_models(df=iris,yname=c("Sepal.Length","Sepal.Width"),
-           xname=".",modeltype=c("lm","glm"), drop_non_numeric = TRUE)
-
-
 ## -----------------------------------------------------------------------------
 
 # getall correlations
@@ -153,19 +107,21 @@ head( corrs <- get_var_corr(mtcars,comparison_var="mpg") )
 ## -----------------------------------------------------------------------------
 
 # purely demonstrative
-get_var_corr(iris,"Sepal.Length",other_vars="Petal.Length",drop_columns=c("factor","character"),method="spearman",
+get_var_corr(yields,"height",other_vars="weight",
+             drop_columns=c("factor","character"),method="spearman",
              exact=FALSE)
 
 
 
 ## -----------------------------------------------------------------------------
 
-head(get_var_corr_(mtcars),6)
+head(get_var_corr_(yields),6)
 
 
 ## -----------------------------------------------------------------------------
 
-head(get_var_corr_(mtcars,subset_cols=list(c("mpg","vs"),c("disp","wt")),method="spearman",exact=FALSE))
+head(get_var_corr_(mtcars,subset_cols=list(c("mpg","vs"),c("disp","wt")),
+                   method="spearman",exact=FALSE))
 
 
 ## -----------------------------------------------------------------------------
@@ -186,7 +142,17 @@ plot_corr(mtcars, x="other_var", y="comparison_var",plot_style = "circles",show_
 
 ## -----------------------------------------------------------------------------
 
-head(rowdiff(iris,exclude = "factor",direction = "reverse"))
+head(agg_by_group(yields,.~normal,length))
+
+
+## -----------------------------------------------------------------------------
+
+head(agg_by_group(mtcars,cyl~hp+vs,sum))
+
+
+## -----------------------------------------------------------------------------
+
+head(rowdiff(yields,exclude = "factor",direction = "reverse"))
 
 
 ## -----------------------------------------------------------------------------
